@@ -581,7 +581,7 @@ static int account_all_refs(int do_qgroups, u64 search_subvol)
 	ulist_free(roots);
 	return 0;
 enomem:
-	error_msg(ERROR_MSG_MEMORY, "accounting for refs for qgroups");
+	error_mem("accounting for refs for qgroups");
 	return -ENOMEM;
 }
 
@@ -960,9 +960,9 @@ loop:
 	 * items. The 2nd pass picks up relation items and glues them to their
 	 * respective count structures.
 	 */
-	key.offset = 0;
 	key.objectid = search_relations ? 0 : BTRFS_QGROUP_RELATION_KEY;
 	key.type = 0;
+	key.offset = 0;
 
 	ret = btrfs_search_slot(NULL, root, &key, &path, 0, 0);
 	if (ret < 0) {
@@ -1011,7 +1011,7 @@ loop:
 			count = alloc_count(&disk_key, leaf, item);
 			if (!count) {
 				ret = ENOMEM;
-				error_msg(ERROR_MSG_MEMORY, NULL);
+				error_mem(NULL);
 				goto out;
 			}
 
@@ -1052,7 +1052,7 @@ static int simple_quota_account_extent(struct btrfs_fs_info *info,
 	u64 generation;
 	int type;
 	u64 root;
-	struct ulist *roots = ulist_alloc(0);
+	struct ulist roots;
 	int ret;
 	struct extent_buffer *node_eb;
 
@@ -1084,9 +1084,10 @@ static int simple_quota_account_extent(struct btrfs_fs_info *info,
 	if (!is_fstree(root))
 		return 0;
 
-	ulist_add(roots, root, 0, 0);
-	ret = account_one_extent(roots, bytenr, num_bytes);
-	ulist_free(roots);
+	ulist_init(&roots);
+	ulist_add(&roots, root, 0, 0);
+	ret = account_one_extent(&roots, bytenr, num_bytes);
+	ulist_release(&roots);
 	return ret;
 }
 
@@ -1591,7 +1592,7 @@ int print_extent_state(struct btrfs_fs_info *info, u64 subvol)
 
 	tree_blocks = ulist_alloc(0);
 	if (!tree_blocks) {
-		error_msg(ERROR_MSG_MEMORY, "allocate ulist");
+		error_mem("allocate ulist");
 		return ENOMEM;
 	}
 
