@@ -82,15 +82,15 @@ static int prop_read_only(enum prop_object_type type,
 		bool is_ro = false;
 		bool do_clear_received_uuid = false;
 
-		if (!strcmp(value, "true")) {
+		if (strcmp(value, "true") == 0) {
 			read_only = true;
-		} else if (!strcmp(value, "false")) {
+		} else if (strcmp(value, "false") == 0) {
 			read_only = false;
 		} else {
 			error("invalid value for property: %s", value);
 			return -EINVAL;
 		}
-		err = btrfs_util_get_subvolume_read_only(object, &is_ro);
+		err = btrfs_util_subvolume_get_read_only(object, &is_ro);
 		if (err) {
 			error_btrfs_util(err);
 			return -errno;
@@ -99,7 +99,7 @@ static int prop_read_only(enum prop_object_type type,
 		if (is_ro && read_only)
 			return 0;
 
-		err = btrfs_util_subvolume_info(object, 0, &info);
+		err = btrfs_util_subvolume_get_info(object, 0, &info);
 		if (err)
 			warning("cannot read subvolume info");
 		if (is_ro && !uuid_is_null(info.received_uuid)) {
@@ -118,7 +118,7 @@ static int prop_read_only(enum prop_object_type type,
 		if (!is_ro && !uuid_is_null(info.received_uuid))
 			warning("read-write subvolume with received_uuid, this is bad");
 
-		err = btrfs_util_set_subvolume_read_only(object, read_only);
+		err = btrfs_util_subvolume_set_read_only(object, read_only);
 		if (err) {
 			error_btrfs_util(err);
 			return -errno;
@@ -135,7 +135,7 @@ static int prop_read_only(enum prop_object_type type,
 				warning("failed to clear received_uuid: %m");
 		}
 	} else {
-		err = btrfs_util_get_subvolume_read_only(object, &read_only);
+		err = btrfs_util_subvolume_get_read_only(object, &read_only);
 		if (err) {
 			error_btrfs_util(err);
 			return -errno;
@@ -273,7 +273,7 @@ static int parse_prop(const char *arg, const struct prop_handler *props,
 	const struct prop_handler *prop = props;
 
 	for (; prop->name; prop++) {
-		if (!strcmp(prop->name, arg)) {
+		if (strcmp(prop->name, arg) == 0) {
 			*prop_ret = prop;
 			return 0;
 		}
@@ -321,7 +321,7 @@ static int check_is_root(const char *object)
 		ret = -errno;
 		goto out;
 	}
-	if (!strcmp(rp, "/")) {
+	if (strcmp(rp, "/") == 0) {
 		ret = 0;
 		goto out;
 	}
@@ -541,16 +541,16 @@ static int parse_args(const struct cmd_struct *cmd, int argc, char **argv,
 
 	*types = 0;
 	if (type_str) {
-		if (!strcmp(type_str, "s") || !strcmp(type_str, "subvol")) {
+		if (strcmp(type_str, "s") == 0 || strcmp(type_str, "subvol") == 0) {
 			*types = prop_object_subvol;
-		} else if (!strcmp(type_str, "f") ||
-			   !strcmp(type_str, "filesystem")) {
+		} else if (strcmp(type_str, "f") == 0 ||
+			   strcmp(type_str, "filesystem") == 0) {
 			*types = prop_object_root;
-		} else if (!strcmp(type_str, "i") ||
-			   !strcmp(type_str, "inode")) {
+		} else if (strcmp(type_str, "i") == 0 ||
+			   strcmp(type_str, "inode") == 0) {
 			*types = prop_object_inode;
-		} else if (!strcmp(type_str, "d") ||
-			   !strcmp(type_str, "device")) {
+		} else if (strcmp(type_str, "d") == 0 ||
+			   strcmp(type_str, "device") == 0) {
 			*types = prop_object_dev;
 		} else {
 			error("invalid object type: %s", type_str);
