@@ -87,13 +87,14 @@ int check_argc_max(int nargs, int expected)
 /*
  * Preprocess @argv with getopt_long to reorder options and consume the "--"
  * option separator.
- * Unknown short and long options are reported, optionally the @usage is printed
- * before exit.
+ * Unknown short and long options are reported. Also consume the --help
+ * option in case it's for a command without any options.
  */
 void clean_args_no_options(const struct cmd_struct *cmd, int argc, char *argv[])
 {
 	static const struct option long_options[] = {
-		{NULL, 0, NULL, 0}
+		{ "help", no_argument, NULL, GETOPT_VAL_HELP },
+		{ NULL, 0, NULL, 0 }
 	};
 
 	while (1) {
@@ -103,9 +104,13 @@ void clean_args_no_options(const struct cmd_struct *cmd, int argc, char *argv[])
 			break;
 
 		switch (c) {
-		default:
+		case GETOPT_VAL_HELP:
 			if (cmd->usagestr)
 				usage(cmd, 1);
+			break;
+		default:
+			if (cmd->usagestr)
+				usage_unknown_option(cmd, argv);
 		}
 	}
 }
@@ -527,7 +532,7 @@ void help_command_group(const struct cmd_group *grp, int argc, char **argv)
 	bool full = false;
 
 	if (argc > 1) {
-		if (!strcmp(argv[1], "--full"))
+		if (strcmp(argv[1], "--full") == 0)
 			full = 1;
 		/* The option --box is handled in the caller */
 	}
@@ -535,3 +540,62 @@ void help_command_group(const struct cmd_group *grp, int argc, char **argv)
 	usage_command_group(grp, full, false);
 }
 
+void help_builtin_features(const char *prefix)
+{
+	static const char *features[] = {
+#if EXPERIMENTAL
+		"+"
+#else
+		"-"
+#endif
+		"EXPERIMENTAL",
+#ifdef INJECT
+		"+"
+#else
+		"-"
+#endif
+		"INJECT",
+#ifdef STATIC_BUILD
+		"+"
+#else
+		"-"
+#endif
+		"STATIC",
+#if defined(COMPRESSION_LZO) && COMPRESSION_LZO == 1
+		"+"
+#else
+		"-"
+#endif
+		"LZO",
+#if defined(COMPRESSION_ZSTD) && COMPRESSION_ZSTD == 1
+		"+"
+#else
+		"-"
+#endif
+		"ZSTD",
+#if defined(HAVE_LIBUDEV) && HAVE_LIBUDEV == 1
+		"+"
+#else
+		"-"
+#endif
+		"UDEV",
+#if defined(HAVE_LINUX_FSVERITY_H) && HAVE_LINUX_FSVERITY_H == 1
+		"+"
+#else
+		"-"
+#endif
+		"FSVERITY",
+#if defined(BTRFS_ZONED) && BTRFS_ZONED == 1
+		"+"
+#else
+		"-"
+#endif
+		"ZONED",
+		"CRYPTO=" CRYPTOPROVIDER,
+	};
+
+	printf("%s%s\n", prefix, PACKAGE_STRING);
+	for (int i = 0; i < ARRAY_SIZE(features); i++)
+		printf("%s%s", (i == 0 ? "" : " "), features[i]);
+	putchar('\n');
+}
