@@ -22,7 +22,6 @@
 #include <stdlib.h>
 #include <string.h>
 #include <time.h>
-#include "kernel-shared/accessors.h"
 #include "kernel-shared/uapi/btrfs_tree.h"
 #include "kernel-shared/uapi/btrfs.h"
 #include "kernel-shared/send.h"
@@ -143,7 +142,7 @@ static int read_cmd(struct btrfs_send_stream *sctx)
 		if (!new_read_buf) {
 			ret = -ENOMEM;
 			errno = -ret;
-			error_msg(ERROR_MSG_MEMORY, "read buffer for command");
+			error_mem("read buffer for command");
 			goto out;
 		}
 		sctx->read_buf = new_read_buf;
@@ -634,7 +633,7 @@ int btrfs_read_and_process_send_stream(int fd,
 	sctx.read_buf = malloc(BTRFS_SEND_BUF_SIZE_V1);
 	if (!sctx.read_buf) {
 		ret = -ENOMEM;
-		error_msg(ERROR_MSG_MEMORY, "send stream read buffer");
+		error_mem("send stream read buffer");
 		goto out;
 	}
 	sctx.read_buf_size = BTRFS_SEND_BUF_SIZE_V1;
