@@ -6,7 +6,6 @@
 #include "kerncompat.h"
 #include <stddef.h>
 #include <string.h>
-#include "kernel-lib/bitops.h"
 #include "kernel-shared/extent_io.h"
 #include "kernel-shared/uapi/btrfs.h"
 #include "kernel-shared/uapi/btrfs_tree.h"
@@ -15,14 +14,6 @@
 #define _static_assert(expr)   _Static_assert(expr, #expr)
 #endif
 
-struct btrfs_map_token {
-	struct extent_buffer *eb;
-	char *kaddr;
-	unsigned long offset;
-};
-
-void btrfs_init_map_token(struct btrfs_map_token *token, struct extent_buffer *eb);
-
 /*
  * Some macros to generate set/get functions for the struct fields.  This
  * assumes there is a lefoo_to_cpu for every type, so lets make a simple one
@@ -34,7 +25,7 @@ void btrfs_init_map_token(struct btrfs_map_token *token, struct extent_buffer *e
 
 static inline u8 get_unaligned_le8(const void *p)
 {
-       return *(u8 *)p;
+       return *(const u8 *)p;
 }
 
 static inline void put_unaligned_le8(u8 val, void *p)
@@ -48,21 +39,16 @@ static inline void put_unaligned_le8(u8 val, void *p)
 			    offsetof(type, member),			\
 			   sizeof(((type *)0)->member)))
 
-#define write_eb_member(eb, ptr, type, member, result) (\
-	write_extent_buffer(eb, (char *)(result),			\
+#define write_eb_member(eb, ptr, type, member, source) (		\
+	write_extent_buffer(eb, (const char *)(source),			\
 			   ((unsigned long)(ptr)) +			\
 			    offsetof(type, member),			\
 			   sizeof(((type *)0)->member)))
 
 #define DECLARE_BTRFS_SETGET_BITS(bits)					\
-u##bits btrfs_get_token_##bits(struct btrfs_map_token *token,		\
-			       const void *ptr, unsigned long off);	\
-void btrfs_set_token_##bits(struct btrfs_map_token *token,		\
-			    const void *ptr, unsigned long off,		\
-			    u##bits val);				\
 u##bits btrfs_get_##bits(const struct extent_buffer *eb,		\
 			 const void *ptr, unsigned long off);		\
-void btrfs_set_##bits(const struct extent_buffer *eb, void *ptr,	\
+void btrfs_set_##bits(struct extent_buffer *eb, void *ptr,		\
 		      unsigned long off, u##bits val);
 
 DECLARE_BTRFS_SETGET_BITS(8)
@@ -77,36 +63,26 @@ static inline u##bits btrfs_##name(const struct extent_buffer *eb,	\
 	_static_assert(sizeof(u##bits) == sizeof(((type *)0))->member);	\
 	return btrfs_get_##bits(eb, s, offsetof(type, member));		\
 }									\
-static inline void btrfs_set_##name(const struct extent_buffer *eb, type *s, \
+static inline void btrfs_set_##name(struct extent_buffer *eb, type *s, \
 				    u##bits val)			\
 {									\
 	_static_assert(sizeof(u##bits) == sizeof(((type *)0))->member);	\
 	btrfs_set_##bits(eb, s, offsetof(type, member), val);		\
 }									\
-static inline u##bits btrfs_token_##name(struct btrfs_map_token *token,	\
-					 const type *s)			\
-{									\
-	_static_assert(sizeof(u##bits) == sizeof(((type *)0))->member);	\
-	return btrfs_get_token_##bits(token, s, offsetof(type, member));\
-}									\
-static inline void btrfs_set_token_##name(struct btrfs_map_token *token,\
-					  type *s, u##bits val)		\
-{									\
-	_static_assert(sizeof(u##bits) == sizeof(((type *)0))->member);	\
-	btrfs_set_token_##bits(token, s, offsetof(type, member), val);	\
-}
 
 /*
  * MODIFIED:
  *  - We have eb->data, not eb->folios[0]
+ *  - no const for extent buffer in btrfs_set_*, buffer is local, in kernel
+ *    it's indirection to pages/folios
  */
 #define BTRFS_SETGET_HEADER_FUNCS(name, type, member, bits)		\
 static inline u##bits btrfs_##name(const struct extent_buffer *eb)	\
 {									\
-	const type *p = (type *)eb->data;				\
+	const type *p = (const type *)eb->data;				\
 	return get_unaligned_le##bits(&p->member);			\
 }									\
-static inline void btrfs_set_##name(const struct extent_buffer *eb,	\
+static inline void btrfs_set_##name(struct extent_buffer *eb,		\
 				    u##bits val)			\
 {									\
 	type *p = (type *)eb->data;					\
@@ -133,8 +109,9 @@ static inline u64 btrfs_device_total_bytes(const struct extent_buffer *eb,
 /*
  * MODIFIED
  *  - Removed WARN_ON(!IS_ALIGNED(val, eb->fs_info->sectorsize));
+ *  - no const for extent buffer
  */
-static inline void btrfs_set_device_total_bytes(const struct extent_buffer *eb,
+static inline void btrfs_set_device_total_bytes(struct extent_buffer *eb,
 						struct btrfs_dev_item *s,
 						u64 val)
 {
@@ -322,12 +299,10 @@ BTRFS_SETGET_FUNCS(timespec_nsec, struct btrfs_timespec, nsec, 32);
 BTRFS_SETGET_STACK_FUNCS(stack_timespec_sec, struct btrfs_timespec, sec, 64);
 BTRFS_SETGET_STACK_FUNCS(stack_timespec_nsec, struct btrfs_timespec, nsec, 32);
 
-BTRFS_SETGET_FUNCS(stripe_extent_encoding, struct btrfs_stripe_extent, encoding, 8);
 BTRFS_SETGET_FUNCS(raid_stride_devid, struct btrfs_raid_stride, devid, 64);
-BTRFS_SETGET_FUNCS(raid_stride_offset, struct btrfs_raid_stride, offset, 64);
-BTRFS_SETGET_STACK_FUNCS(stack_stripe_extent_encoding,
-			 struct btrfs_stripe_extent, encoding, 8);
+BTRFS_SETGET_FUNCS(raid_stride_physical, struct btrfs_raid_stride, physical, 64);
 BTRFS_SETGET_STACK_FUNCS(stack_raid_stride_devid, struct btrfs_raid_stride, devid, 64);
+BTRFS_SETGET_STACK_FUNCS(stack_raid_stride_physical, struct btrfs_raid_stride, physical, 64);
 
 static inline struct btrfs_raid_stride *btrfs_raid_stride_nr(
 						 struct btrfs_stripe_extent *dps,
@@ -347,11 +322,11 @@ static inline u64 btrfs_raid_stride_devid_nr(struct extent_buffer *eb,
 	return btrfs_raid_stride_devid(eb, btrfs_raid_stride_nr(dps, nr));
 }
 
-static inline u64 btrfs_raid_stride_offset_nr(struct extent_buffer *eb,
+static inline u64 btrfs_raid_stride_physical_nr(struct extent_buffer *eb,
 					      struct btrfs_stripe_extent *dps,
 					      int nr)
 {
-	return btrfs_raid_stride_offset(eb, btrfs_raid_stride_nr(dps, nr));
+	return btrfs_raid_stride_physical(eb, btrfs_raid_stride_nr(dps, nr));
 }
 
 /* struct btrfs_dev_extent */
@@ -382,9 +357,9 @@ static inline void btrfs_tree_block_key(const struct extent_buffer *eb,
 	read_eb_member(eb, item, struct btrfs_tree_block_info, key, key);
 }
 
-static inline void btrfs_set_tree_block_key(const struct extent_buffer *eb,
+static inline void btrfs_set_tree_block_key(struct extent_buffer *eb,
 					    struct btrfs_tree_block_info *item,
-					    struct btrfs_disk_key *key)
+					    const struct btrfs_disk_key *key)
 {
 	write_eb_member(eb, item, struct btrfs_tree_block_info, key, key);
 }
@@ -438,7 +413,7 @@ static inline u64 btrfs_node_blockptr(const struct extent_buffer *eb, int nr)
 	return btrfs_key_blockptr(eb, (struct btrfs_key_ptr *)ptr);
 }
 
-static inline void btrfs_set_node_blockptr(const struct extent_buffer *eb,
+static inline void btrfs_set_node_blockptr(struct extent_buffer *eb,
 					   int nr, u64 val)
 {
 	unsigned long ptr;
@@ -457,7 +432,7 @@ static inline u64 btrfs_node_ptr_generation(const struct extent_buffer *eb, int
 	return btrfs_key_generation(eb, (struct btrfs_key_ptr *)ptr);
 }
 
-static inline void btrfs_set_node_ptr_generation(const struct extent_buffer *eb,
+static inline void btrfs_set_node_ptr_generation(struct extent_buffer *eb,
 						 int nr, u64 val)
 {
 	unsigned long ptr;
@@ -476,8 +451,8 @@ static inline unsigned long btrfs_node_key_ptr_offset(const struct extent_buffer
 void btrfs_node_key(const struct extent_buffer *eb,
 		    struct btrfs_disk_key *disk_key, int nr);
 
-static inline void btrfs_set_node_key(const struct extent_buffer *eb,
-				      struct btrfs_disk_key *disk_key, int nr)
+static inline void btrfs_set_node_key(struct extent_buffer *eb,
+				      const struct btrfs_disk_key *disk_key, int nr)
 {
 	unsigned long ptr;
 
@@ -508,22 +483,10 @@ static inline u32 btrfs_item_##member(const struct extent_buffer *eb, int slot)
 {										\
 	return btrfs_raw_item_##member(eb, btrfs_item_nr(eb, slot));		\
 }										\
-static inline void btrfs_set_item_##member(const struct extent_buffer *eb,	\
+static inline void btrfs_set_item_##member(struct extent_buffer *eb,	\
 					   int slot, u32 val)			\
 {										\
 	btrfs_set_raw_item_##member(eb, btrfs_item_nr(eb, slot), val);		\
-}										\
-static inline u32 btrfs_token_item_##member(struct btrfs_map_token *token,	\
-					    int slot)				\
-{										\
-	struct btrfs_item *item = btrfs_item_nr(token->eb, slot);		\
-	return btrfs_token_raw_item_##member(token, item);			\
-}										\
-static inline void btrfs_set_token_item_##member(struct btrfs_map_token *token,	\
-						 int slot, u32 val)		\
-{										\
-	struct btrfs_item *item = btrfs_item_nr(token->eb, slot);		\
-	btrfs_set_token_raw_item_##member(token, item, val);			\
 }
 
 BTRFS_ITEM_SETGET_FUNCS(offset)
@@ -543,7 +506,7 @@ static inline void btrfs_item_key(const struct extent_buffer *eb,
 }
 
 static inline void btrfs_set_item_key(struct extent_buffer *eb,
-				      struct btrfs_disk_key *disk_key, int nr)
+				      const struct btrfs_disk_key *disk_key, int nr)
 {
 	struct btrfs_item *item = btrfs_item_nr(eb, nr);
 
@@ -670,9 +633,9 @@ static inline void btrfs_dir_item_key_to_cpu(const struct extent_buffer *eb,
 static inline void btrfs_disk_key_to_cpu(struct btrfs_key *cpu,
 					 const struct btrfs_disk_key *disk)
 {
-	cpu->objectid = le64_to_cpu(disk->objectid);
-	cpu->type = disk->type;
 	cpu->offset = le64_to_cpu(disk->offset);
+	cpu->type = disk->type;
+	cpu->objectid = le64_to_cpu(disk->objectid);
 }
 
 static inline void btrfs_cpu_key_to_disk(struct btrfs_disk_key *disk,
