@@ -15,7 +15,6 @@
 # You should have received a copy of the GNU Lesser General Public License
 # along with libbtrfsutil.  If not, see <http://www.gnu.org/licenses/>.
 
-import fcntl
 import errno
 import multiprocessing
 import os
@@ -72,7 +71,7 @@ class TestSubvolume(BtrfsTestCase):
         except Exception:
             pass
         finally:
-            # btrfs_util_subvolume_id_fd() had a bug that would erroneously
+            # btrfs_util_subvolume_get_id_fd() had a bug that would erroneously
             # close the provided file descriptor. In that case, this will fail
             # with EBADF.
             os.close(fd)
