@@ -3,7 +3,7 @@
  *
  * libbtrfsutil is free software: you can redistribute it and/or modify
  * it under the terms of the GNU Lesser General Public License as published by
- * the Free Software Foundation, either version 3 of the License, or
+ * the Free Software Foundation, either version 2.1 of the License, or
  * (at your option) any later version.
  *
  * libbtrfsutil is distributed in the hope that it will be useful,
@@ -16,6 +16,9 @@
  */
 
 #ifndef _LIBBTRFSUTIL_STUBS_H_
+#define _LIBBTRFSUTIL_STUBS_H_
+
+#include <stddef.h>
 
 void *reallocarray(void *ptr, size_t nmemb, size_t size);
 
