@@ -1,11 +1,12 @@
 #!/bin/bash
 # Detect if subvolume deletion fails when it's part of send
 
-source "$TEST_TOP/common"
+source "$TEST_TOP/common" || exit
 
 check_prereq mkfs.btrfs
 check_prereq btrfs
 
+setup_root_helper
 prepare_test_dev 4G
 
 run_check_mkfs_test_dev
