@@ -12,7 +12,7 @@ setup_root_helper
 prepare_test_dev
 
 if ! [ -f "/sys/fs/btrfs/features/send_stream_version" ] ||
-   grep -s '1$' "/sys/fs/btrfs/features/send_stream_version"; then
+   grep -q '1$' "/sys/fs/btrfs/features/send_stream_version"; then
 	_not_run "kernel does not support send stream >1"
 	exit
 fi
@@ -22,7 +22,8 @@ here=`pwd`
 # assumes the filesystem exists, and does mount, write, snapshot, send, unmount
 # for the specified encoding option
 send_one() {
-	local str
+	local algorithm
+	local file
 	local subv
 	local snap
 
